@@ -2,7 +2,7 @@
 # Package       HiPi::Device::GPIO
 # Description:  System GPIO Device
 # Created       Wed Feb 20 02:40:29 2013
-# SVN Id        $Id: GPIO.pm 1076 2013-03-13 08:55:10Z Mark Dootson $
+# SVN Id        $Id: GPIO.pm 1589 2013-03-19 07:33:09Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -63,7 +63,7 @@ sub export_pin {
     # export the pin
     
     if( !-d $pinroot ) {
-        HiPi::system_sudo_shell(qq(echo $pinno > /sys/class/gpio/export)) and croak qq(failed to export pin $pinno : $!);
+        HiPi::system_sudo_shell(qq(/bin/echo $pinno > /sys/class/gpio/export)) and croak qq(failed to export pin $pinno : $!);
     }
     if( $gname ) {
         # change exported permissions
@@ -80,7 +80,7 @@ sub unexport_pin {
     my $pinroot = '/sys/class/gpio/gpio' . $pinno;
     return if !-d $pinroot;
     # unexport the pin
-    HiPi::system_sudo_shell( qq(echo $pinno > /sys/class/gpio/unexport) ) and croak qq(failed to unexport pin $pinno : $!);
+    HiPi::system_sudo_shell( qq(/bin/echo $pinno > /sys/class/gpio/unexport) ) and croak qq(failed to unexport pin $pinno : $!);
 }
 
 sub pin_status {
